(define-module (glicid-tainted packages staging)
  #:use-module (guix gexp)
  #:use-module (guix download)
  #:use-module (guix packages)
  #:use-module (guix build-system python)
  #:use-module ((guix licenses)  #:prefix license:)
  #:use-module (gnu packages python-xyz)
  #:use-module (guix-science packages jupyter)
  #:use-module (gnu packages python-science)
  #:use-module (gnu packages machine-learning)
  #:use-module (gnu packages version-control)
  #:use-module (gnu packages check)
  #:use-module (gnu packages xml)
  #:use-module (gnu packages python-web)
  #:use-module (gnu packages python-build)
  #:use-module (gnu packages databases)
  #:use-module (gnu packages geo)
  #:use-module (gnu packages python-check)
  #:use-module (guix-science-nonfree packages machine-learning)
  #:use-module (glicid packages mpi)
  #:use-module (guix-science-nonfree packages linux)
  #:use-module (guix-science-nonfree packages cuda)
  #:use-module (guix utils)
  #:use-module (guix git-download)
  #:use-module (guix build-system pyproject)



)

;(use-modules (guix packages)
;             (guix download)
;)

(define-public python-pytest-json-report
 (package
  (name "python-pytest-json-report")
  (version "1.5.0")
  (source (origin
            (method url-fetch)
            (uri (pypi-uri "pytest-json-report" version))
            (sha256
             (base32
              "1phmqr6x78yygpr79mkp43xnxrm6221rwwh06xgrp8aig1j3rpid"))))
  (build-system python-build-system)
  (propagated-inputs (list python-pytest python-pytest-metadata))
  (home-page "https://github.com/numirias/pytest-json-report")
  (synopsis "A pytest plugin to report test results as JSON files")
  (description
   "This package provides a pytest plugin to report test results as JSON files")
  (license license:expat))
)

(define-public python-obspy
 (package
  (name "python-obspy")
  (version "1.4.0")
  (source (origin
            (method url-fetch)
            (uri (pypi-uri "obspy" version))
            (sha256
             (base32
              "01jwzsjym35vc851hk5myd9qw2kjvp0mvjvkh6q34ms8k8fnwsik"))))
   (build-system python-build-system)
    (arguments 
     '(#:tests? #f)) ;;; try to access service.iris.edu

  (propagated-inputs (list python-decorator
                           python-lxml
                           python-matplotlib
                           python-numpy
                           python-requests
                           python-scipy
                           python-setuptools
                           python-sqlalchemy))
  (native-inputs (list python-packaging python-pyproj python-pytest
                       python-pytest-json-report))
  (home-page "https://www.obspy.org")

  (synopsis "ObsPy - a Python framework for seismological observatories.")
  (description "ObsPy - a Python framework for seismological observatories.")
  (license #f))
)

(define-public python-seisbench
 (package
  (name "python-seisbench")
  (version "0.3.2")
  (source (origin
;            (method url-fetch)

                           (method git-fetch)
                           (uri (git-reference
                                  (url "https://github.com/seisbench/seisbench")
                                  (commit (string-append "v" version))))

             
;            (uri (pypi-uri "seisbench" version))
          
;            (patches (search-patches "glicid-non-free/glicid-tainted/packages/patches/seisbench-version-and-data.patch"))))))

            (sha256
             (base32
;              "1n04pr8ri06q6ngyi8wnw13vhhw2w7kkhn87zrkbjjw49v157xzg"
	       "0jf0s17lrbdcj18wzfbmg37gknay854mfnnmshh4il9xakph1s0g"

))))

(build-system python-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
          (add-before 'build 'pretend-version
            ;; The version string is usually derived via setuptools-scm, but
            ;; it doesn't work without the .git directory.
            (lambda _
              (setenv "SETUPTOOLS_SCM_PRETEND_VERSION" #$version))))))


;                  (delete 'check)
;                  (delete 'sanity-check)

  (propagated-inputs (list python-h5py
                           python-nest-asyncio
                           python-numpy
                           python-obspy
                           python-pandas
                           python-scipy
                           python-pytorch
                           python-tqdm))
  (native-inputs (list python-black
                       python-flake8
                       python-isort
                       python-pre-commit
                       python-pytest
                       python-pytest-asyncio))
  (home-page "")
  (synopsis "The seismological machine learning benchmark collection")
  (description "The seismological machine learning benchmark collection")
  (license #f))
)


(define-public python-seisbench+cuda
 (package
  (inherit python-seisbench)
  (name "python-seisbench+cuda")
  (inputs (modify-inputs (package-inputs python-seisbench)
              (delete python-pytorch)
              (prepend python-pytorch-with-cuda11)))

 )
)

(define-public python-esa-ptr
 (package
  (name "python-esa-ptr")
  (version "1.2")
  (source (origin
            (method url-fetch)
            (uri (pypi-uri "esa_ptr" version))
            (sha256
             (base32
              "1jjny1jsmircny4v5vyqb1hwan839gxdmwljh647b895qvqgr0lb"))))
  (build-system python-build-system)
  (home-page "https://juigitlab.esac.esa.int/python/ptr")
  (synopsis "ESA Planning Timeline Request package")
  (description "ESA Planning Timeline Request package")
  (license #f)))


#! (define-public python-spiceypy
 (package
  (name "python-spiceypy")
  (version "5.1.2")
  (source (origin
            (method url-fetch)
            (uri (pypi-uri "spiceypy" version))
            (sha256
             (base32
              "10n0ia9q8f2fs7g8sycjvzgqmhl838vx1yb4f6jn5fl17q6yg7y9"))))
  (build-system python-build-system)
  (propagated-inputs (list python-numpy))
  (native-inputs (list python-black
                       python-build
                       python-codecov
                       python-coverage
                       python-numpy
                       python-pandas
                       python-pytest
                       python-twine
                       python-wheel))
  (home-page "https://github.com/AndrewAnnex/SpiceyPy")
  (synopsis "A Python Wrapper for the NAIF CSPICE Toolkit")
  (description
   "This package provides a Python Wrapper for the NAIF CSPICE Toolkit")
  (license license:expat))
)

(package
  (name "python-planetary-coverage")
  (version "1.0.0")
  (source (origin
            (method url-fetch)
            (uri (pypi-uri "planetary_coverage" version))
            (sha256
             (base32
              "17xv4i9k5h4p9bc5j2x3xa2malh77b4wnckk0kyghz5y560hbds4"))))
  (build-system python-build-system)
  (propagated-inputs (list python-esa-ptr python-matplotlib python-numpy
                           python-pillow python-spiceypy))
  (home-page "https://juigitlab.esac.esa.int/python/planetary-coverage")
  (synopsis "Planetary coverage package")
  (description "Planetary coverage package")
  (license #f))
!#


(define-public openmpi-glicid+cuda
 (package
  (inherit openmpi-glicid)
  (name "openmpi-glicid+cuda")
  (arguments

   (substitute-keyword-arguments (package-arguments openmpi-glicid)
       ((#:configure-flags flags #~'())
        #~(append (list (string-append "--with-cuda="
                                       #$(this-package-input "cuda-toolkit"))
                        "--enable-mpi-ext=cuda")
                  #$flags))))
    (inputs (modify-inputs (package-inputs openmpi-glicid)
              (append cuda)
              (replace "psm2-upstream" psm2-cuda))) ; todo : psm2-upstream
    (synopsis "MPI-3 implementation, with CUDA support"))


)

;openmpi-glicid+cuda
;python-seisbench
;
;
;
;

(define-public python-seisbench2
  (package
    (name "python-seisbench2")
    (version "0.4.0")
    (source
     (origin
       (method git-fetch)
       (uri (git-reference
        (url "https://github.com/seisbench/seisbench")
                                  (commit (string-append "v" version))))

       (file-name (git-file-name "python-seisbench2" version))
       (sha256
        (base32
;         "0jf0s17lrbdcj18wzfbmg37gknay854mfnnmshh4il9xakph1s0g"
	  "0f0gx1z2fv17qijsvvriv9gfii8rs44pxyg466h76zpdkms0scd2"

))))
    (build-system pyproject-build-system)
    (arguments
     (list
      #:phases
      #~(modify-phases %standard-phases
      (add-after 'unpack 'fix-build-environment
            (lambda _
              (delete-file "setup.py")))

          (add-before 'build 'pretend-version
            ;; The version string is usually derived via setuptools-scm, but
            ;; it doesn't work without the .git directory.
            (lambda _
                  (setenv "SETUPTOOLS_SCM_PRETEND_VERSION" #$version))

                  (delete 'check)
                  (delete 'sanity-check))
)))

  (propagated-inputs (list python-h5py
                           python-nest-asyncio
                           python-numpy
                           python-obspy
                           python-pandas
                           python-scipy
                           python-pytorch
                           python-tqdm))
  (native-inputs (list python-black
                       python-flake8
                       python-isort
                       python-pre-commit
                       python-pytest
                       python-pytest-asyncio))


    (home-page "https://github.com/aertslab/ctxcore")
    (synopsis "Core functions for pycisTarget and the SCENIC tool suite")
    (description
     "ctxcore is part of the SCENIC suite of tools.  It provides core functions for
pycisTarget and SCENIC.")
    (license license:gpl3+)))

python-seisbench2
